Enumeration

GskSnapDirection

unstable since: 4.24

Declaration

enum Gsk.SnapDirection

Description [src]

Specifies how a coordinate should be snapped to the pixel grid.

Note that the top and left sides of rectangles need to be snapped in the opposite direction from the bottom and right sides to make the rectangle grow or shrink.

Available since: 4.24

Members

GSK_SNAP_NONE

Don’t snap the value.

  • Value: 0
  • Available since: 4.24
GSK_SNAP_FLOOR

Use floor() to snap.

  • Value: 1
  • Available since: 4.24
GSK_SNAP_CEIL

Use ceil() to snap.

  • Value: 2
  • Available since: 4.24
GSK_SNAP_ROUND

Use round() to snap.

  • Value: 3
  • Available since: 4.24